Module: Postburner::Callbacks
- Extended by:
- ActiveSupport::Concern
- Includes:
- ActiveSupport::Callbacks
- Included in:
- Job
- Defined in:
- app/concerns/postburner/callbacks.rb
Overview
Postburner Job Callbacks
Postburner Job provides hooks during the life cycle of a job. Callbacks allow you to trigger logic during this cycle. In called order, available callbacks are:
- before_enqueue
- after_enqueue
- before_attempt
- before_processing
- after_processing
- after_processed
- after_attempt
Around callbacks are also defined:
- around_enqueue
- around_attempt
- around_processing
NOTE: Calling the same callback multiple times will overwrite previous callback definitions.
Defined Under Namespace
Modules: ClassMethods