Exception: Postburner::Job::MalformedResponse
- Inherits:
-
StandardError
- Object
- StandardError
- Postburner::Job::MalformedResponse
- Defined in:
- app/models/postburner/job.rb
Overview
Exception raised when a queue strategy returns an invalid response format.
Queue strategies must return a Hash with an ‘:id` key when inserting jobs. The `:id` value represents the Beanstalkd job ID (can be nil for test strategies). This exception is raised in Insertion#insert! when a strategy returns a malformed response.