Exception: Postburner::Job::PrematurePerform
- Inherits:
-
StandardError
- Object
- StandardError
- Postburner::Job::PrematurePerform
- Defined in:
- app/models/postburner/job.rb
Overview
Exception raised when a job is executed before its scheduled run_at time.
In production (Queue/NiceQueue), this is handled by re-inserting with delay. In test mode (TestQueue), this exception is raised to force explicit time management.